@@ -2,14 +2,12 @@
 #'
 #' Function for downloading GHCN v2.
 #'
-#' @importFrom methods is
 #' @importFrom utils download.file
-#' @param folder_path a character string with the path where the "raw" folder is located.
+#' @param folder_path a character string with the path where the data will be downloaded.
 #' @return No return value, called to download the data set.
 #' @keywords internal
 
-download_ghcn <- function(folder_path = "./data/raw/"){
-  if (!is.character(folder_path)) stop ("folder_path should be a character string.")
+download_ghcn <- function(folder_path = "."){
   old_options <- options()
   options(timeout = 6000)
   on.exit(options(old_options))
@@ -17,6 +15,6 @@ download_ghcn <- function(folder_path = "./data/raw/"){
   zenodo_end <- "?download=1"
   file_name <- "ghcn_tp_mm_land_190001_201505_025_monthly.nc"
   file_url <- paste0(zenodo_base, file_name, zenodo_end)
-  file_destination <- paste0(folder_path, file_name)
+  file_destination <- paste(folder_path, file_name, sep = "/")
   download.file(file_url, file_destination, mode = "wb")
 }
\ No newline at end of file
